@@ -19,6 +19,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 // Implementation of MainDialog
 
+#include <KIconLoader>
+#include <KPixmapSequence>
+
 #include <QMessageBox>
 #include <QFileDialog>
 #include <QDropEvent>
@@ -30,6 +33,7 @@
 #include <QRegularExpression>
 #include <QDebug>
 #include <QLoggingCategory>
+#include <QMovie>
 
 #include "common.h"
 #include "mainapplication.h"
@@ -41,6 +45,7 @@
 #include "verifyneoniso.h"
 #include "verifynetrunneriso.h"
 #include "verifykubuntuiso.h"
+#include "verifyarchiso.h"
 
 MainDialog::MainDialog(QWidget *parent) :
     QDialog(parent),
@@ -134,7 +139,23 @@ void MainDialog::preprocessImageFile(const QString& newImageFile)
     f.close();
     m_ImageFile = newImageFile;
     ui->imageEdit->setText(QDir::toNativeSeparators(m_ImageFile) + " " + i18n("(%1 MiB)", QString::number(alignNumberDiv(m_ImageSize, DEFAULT_UNIT))));
+
+    m_busyWidget = new KPixmapSequenceOverlayPainter(this);
+    m_busyWidget->setSequence(KIconLoader::global()->loadPixmapSequence("process-working", KIconLoader::SizeSmallMedium));
+    m_busyWidget->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+    m_busyWidget->setWidget(ui->busySpinner);
+    ui->busySpinner->setFixedSize(24, 24);
+    ui->busySpinner->show();
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+    m_busyWidget->start();
+
     IsoResult isoResult = verifyISO();
+
+    ui->busySpinner->hide();
+    m_busyWidget->stop();
+    QApplication::setOverrideCursor(Qt::ArrowCursor);
+    delete m_busyWidget;
+    
     if (isoResult.resultType == Invalid) {
         QMessageBox::critical(this, i18n("Invalid ISO"), i18n("ISO is invalid:<p>%1", isoResult.error));
         return;
@@ -311,7 +332,8 @@ void MainDialog::enumFlashDevices()
 // much more generic to avoid overhead and repetition
 IsoResult MainDialog::verifyISO() {
     ui->verificationResultLabel->show();
-    ui->verificationResultLabel->setText(i18n("Running ISO verifiction, please wait..."));
+    ui->verificationResultLabel->setText(i18n("Running ISO verification, please wait..."));
+
     QCoreApplication::instance()->processEvents();
     IsoResult result;
     VerifyNeonISO verifyNeon(m_ImageFile);
@@ -330,6 +352,22 @@ IsoResult MainDialog::verifyISO() {
             return result;
         }
     }
+    VerifyArchISO verifyArch(m_ImageFile);
+    if (verifyArch.canVerify()) {
+        if (verifyArch.isValid()) {
+            ui->verificationResultLabel->setText(i18n("Verified as valid Arch ISO"));
+            result.resultType = Fine;
+            result.error = i18n("Verified as valid Arch ISO");
+            return result;
+        } else {
+            QString error(i18n("Invalid Arch image"));
+            ui->verificationResultLabel->show();
+            ui->verificationResultLabel->setText(verifyArch.m_error);
+            result.resultType = Invalid;
+            result.error = verifyArch.m_error;
+            return result;
+        }
+    }
     VerifyNetrunnerISO verifyNetrunner(m_ImageFile);
     if (verifyNetrunner.canVerify()) {
         if (verifyNetrunner.isValid()) {
@@ -437,6 +475,7 @@ void MainDialog::cancelWriting() {
 }
 
 void MainDialog::progressStep(KJob* job, unsigned long step) {
+    Q_UNUSED(job)
     qCDebug(ISOIMAGEWRITER_LOG) << "progressStep %() " << step;
     updateProgressBar(step);
 }
@@ -523,9 +562,10 @@ void MainDialog::hideWritingProgress()
     ui->deviceList->setEnabled(true);
     ui->deviceRefreshButton->setEnabled(true);
 
-    // Hide the progress bar and verifiction label
+    // Hide the progress bar and verification label
     ui->verificationResultLabel->hide();
     ui->progressBar->setVisible(false);
+    ui->busySpinner->hide();
     ui->progressBarSpacer->changeSize(10, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
     m_writeButton->setVisible(true);
     m_clearButton->setVisible(true);
